@@ -1,23 +1,32 @@
 #ifndef DBUTIL_H
 #define DBUTIL_H
+/*
+ * データベースアクセスユーティリティ
+ */
 #include <stdio.h>
 #include <sqlite3.h>
 #include <stdarg.h>
+#include "util.h"
 
-#define ERROR_LABEL error: \
+#define ERROR_LABEL(db) error: \
     d("ERR: %s\n", sqlite3_errmsg(db)); \
     sqlite3_finalize(stmt); \
     sqlite3_close(db); \
     die("failed to dbaccess.");
 
-void db_init();
-void db_finish();
-void db_begin();
-void db_rollback();
-void db_commit();
+typedef struct {
+    char name[DEFAULT_LENGTH];
+    sqlite3* handle;
+} Database;
 
-int exec_query(const char* sql,...);
-int exec_query_scalar_int(const char* sql, ...);
+Database* db_init(char*);
+void db_finish(Database*);
+void db_begin(Database*);
+void db_rollback(Database*);
+void db_commit(Database*);
+
+int exec_query(Database*, const char* sql,...);
+int exec_query_scalar_int(Database*, const char* sql, ...);
 int exec_and_wait_4_done(sqlite3_stmt*);
 
 #define INVALID_INT -99999
@@ -33,5 +42,7 @@ enum SQLITE_RETURN {
     SQLITE_RETURN_OK,
     SQLITE_RETURN_ERROR
 };
+List* parse_keywords(List*, char*);
+String* create_columns_like_exp(List*, char*, List*, String*);
 #endif
 /* vim: set ts=4 sw=4 sts=4 expandtab fenc=utf-8: */
